@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <stdlib.h>
 #include <ctype.h>
 #include <stdio.h>
+#include <yaz/matchstr.h>
 
 #define SPACECHR " \t\r\n\f"
 
@@ -47,6 +48,7 @@ namespace metaproxy_1 {
         Rep();
         ~Rep();
         int m_verbose;
+        bool nest;
     };
 }
 
@@ -55,6 +57,7 @@ namespace mp = metaproxy_1;
 mp::HTMLParser::Rep::Rep()
 {
     m_verbose = 0;
+    nest = true;
 }
 
 mp::HTMLParser::Rep::~Rep()
@@ -163,8 +166,12 @@ int mp::HTMLParser::Rep::tagAttrs(HTMLParserEvent &event,
         x[0] = tr;
         x[1] = 0;
         if (m_verbose)
-            printf ("------ attr %.*s=%.*s\n", attr_len, attr_name,
-                    val_len, value);
+        {
+            printf("------ attr %.*s", attr_len, attr_name);
+            if (value)
+                printf("=%.*s", val_len, value);
+            printf("\n");
+        }
         event.attribute(name, len, attr_name, attr_len, value, val_len, x);
     }
     return i;
@@ -192,7 +199,7 @@ int mp::HTMLParser::Rep::tagEnd(HTMLParserEvent &event,
     {
         if (m_verbose)
             printf("------ any tag %s %.*s\n",
-                   close_it ? " close" : "end", tag_len, tag);
+                   close_it ? "close" : "end", tag_len, tag);
         event.anyTagEnd(tag, tag_len, close_it);
         i++;
     }
@@ -219,7 +226,7 @@ void mp::HTMLParser::Rep::parse_str(HTMLParserEvent &event, const char *cp)
         if (*cp++ != '<')
             continue;
 
-        if (*cp == '!')
+        if (nest && *cp == '!')
         {
             int i;
             tagText(event, text_start, cp - 1);
@@ -245,7 +252,7 @@ void mp::HTMLParser::Rep::parse_str(HTMLParserEvent &event, const char *cp)
             cp += i;
             text_start = cp;
         }
-        else if (*cp == '?')
+        else if (nest && *cp == '?')
         {
             int i;
             tagText(event, text_start, cp - 1);
@@ -261,9 +268,21 @@ void mp::HTMLParser::Rep::parse_str(HTMLParserEvent &event, const char *cp)
         else if (*cp == '/' && isAlpha(cp[1]))
         {
             int i;
-            tagText(event, text_start, cp - 1);
-
+ 
             i = skipName(++cp);
+
+            if (!nest)
+            {
+                if (i == 6 && !yaz_strncasecmp(cp, "script", i))
+                {
+                    int ws = skipSpace(cp + 6);
+                    if (cp[ws + 6] == '>')
+                        nest = true; /* really terminated */
+                }
+                if (!nest)
+                    continue;
+            }
+            tagText(event, text_start, cp - 2);
             event.closeTag(cp, i);
             if (m_verbose)
                 printf("------ tag close %.*s\n", i, cp);
@@ -271,7 +290,7 @@ void mp::HTMLParser::Rep::parse_str(HTMLParserEvent &event, const char *cp)
             cp += i;
             text_start = cp;
         }
-        else if (isAlpha(*cp))
+        else if (nest && isAlpha(*cp))
         {
             int i, j;
             tagText(event, text_start, cp - 1);
@@ -281,6 +300,10 @@ void mp::HTMLParser::Rep::parse_str(HTMLParserEvent &event, const char *cp)
                 printf("------ tag open %.*s\n", i, cp);
             j = tagAttrs(event, cp, i, cp + i);
             j += tagEnd(event, cp, i, cp + i + j);
+
+            if (i == 6 && !yaz_strncasecmp(cp, "script", i))
+                nest = false;
+
             cp += i + j;
             text_start = cp;
         }
